@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '2.001';
+our $VERSION = '2.111';
 
 sub new {
         my ($class) = @_;
@@ -182,10 +182,36 @@ sub PT::PackageWithoutConstructor::X {
         my ($class, $className) = @_;
 
         my $packageName = $class->{PackageName}->X($className);
+        if(exists $class->{QW}) {
+            my $qw = $class->{QW}->X($className);
+
+            my $packageWithoutConstructor = "use " . $packageName . $qw . ";\n";
+            return $packageWithoutConstructor;
+        }
         my $packageWithoutConstructor = "use " . $packageName . ";\n";
         return $packageWithoutConstructor;
 }
 
+sub PT::QW::X {
+    my ($class, $className) = @_;
+
+    my @functionList = $class->{FunctionList}->X($className);
+    my $qw = " qw(";
+    my $funcitonList = join(" ", @functionList);
+    $qw .= $funcitonList . ")";
+}
+
+sub PT::FunctionList::X {
+    my ($class, $className) = @_;
+
+    my @functionList;
+    for my $element ( @{ $class->{FunctionName}} ) {
+        push @functionList, $element->X($className);
+    }
+
+    return @functionList;
+}
+
 sub PT::Constructor::X {
         my ($class, $className) = @_;
 
@@ -1188,7 +1214,9 @@ my $parser = qr {
     <objrule:  PT::ObjectParameters>           <PackageParams> | <Parameters>
     <objrule:  PT::PackageParams>              <[KeyValue]>+ % <Comma>
     <objrule:  PT::PackageName>                <[PackageDir]>+ % (::)
-    <objrule:  PT::PackageWithoutConstructor>  <PackageName>
+    <objrule:  PT::PackageWithoutConstructor>  <PackageName> <QW>?
+    <objrule:  PT::QW>                         <Dot> <LParen> <FunctionList> <RParen>
+    <objrule:  PT::FunctionList>               <[FunctionName]>+ % <Comma>
     <objrule:  PT::Constructor>                [a-zA-Z]+?
     <objrule:  PT::Object>                     [a-zA-Z]+?
     <objrule:  PT::PackageDir>                 [a-zA-Z]+?
